@@ -39,7 +39,7 @@ import org.apache.tomcat.util.res.StringManager;
 public class BackupManager extends ClusterManagerBase
         implements MapOwner, DistributedManager {
 
-    private final Log log = LogFactory.getLog(BackupManager.class);
+    private final Log log = LogFactory.getLog(BackupManager.class); // must not be static
 
     /**
      * The string manager for this package.
@@ -68,6 +68,11 @@ public class BackupManager extends ClusterManagerBase
      */
     private boolean terminateOnStartFailure = false;
 
+    /**
+     * The timeout for a ping message in replication map.
+     */
+    private long accessTimeout = 5000;
+
     /**
      * Constructor, just calls super()
      *
@@ -144,6 +149,7 @@ public class BackupManager extends ClusterManagerBase
                     this, cluster.getChannel(), rpcTimeout, getMapName(),
                     getClassLoaders(), terminateOnStartFailure);
             map.setChannelSendOptions(mapSendOptions);
+            map.setAccessTimeout(accessTimeout);
             this.sessions = map;
         }  catch ( Exception x ) {
             log.error(sm.getString("backupManager.startUnable", getName()),x);
@@ -215,6 +221,14 @@ public class BackupManager extends ClusterManagerBase
         return terminateOnStartFailure;
     }
 
+    public long getAccessTimeout() {
+        return accessTimeout;
+    }
+
+    public void setAccessTimeout(long accessTimeout) {
+        this.accessTimeout = accessTimeout;
+    }
+
     @Override
     public String[] getInvalidatedSessions() {
         return new String[0];
@@ -227,6 +241,7 @@ public class BackupManager extends ClusterManagerBase
         result.mapSendOptions = mapSendOptions;
         result.rpcTimeout = rpcTimeout;
         result.terminateOnStartFailure = terminateOnStartFailure;
+        result.accessTimeout = accessTimeout;
         return result;
     }
 
