@@ -32,6 +32,8 @@ import java.util.Map;
 
 import org.apache.jasper.JasperException;
 import org.apache.jasper.JspCompilationContext;
+import org.apache.juli.logging.Log;
+import org.apache.juli.logging.LogFactory;
 
 /**
  * Contains static utilities for generating SMAP data based on the
@@ -60,6 +62,7 @@ public class SmapUtil {
      * @param ctxt Current compilation context
      * @param pageNodes The current JSP page
      * @return a SMAP for the page
+     * @throws IOException Error writing SMAP
      */
     public static String[] generateSmap(
         JspCompilationContext ctxt,
@@ -94,14 +97,14 @@ public class SmapUtil {
         **/
 
         // now, assemble info about our own stratum (JSP) using JspLineMap
-        SmapStratum s = new SmapStratum("JSP");
+        SmapStratum s = new SmapStratum();
 
         g.setOutputFileName(unqualify(ctxt.getServletJavaFileName()));
 
         // Map out Node.Nodes
         evaluateNodes(pageNodes, s, map, ctxt.getOptions().getMappedFile());
         s.optimizeLineSection();
-        g.addStratum(s, true);
+        g.setStratum(s);
 
         if (ctxt.getOptions().isSmapDumped()) {
             File outSmap = new File(ctxt.getClassFileName() + ".smap");
@@ -129,7 +132,7 @@ public class SmapUtil {
             s.optimizeLineSection();
             g = new SmapGenerator();
             g.setOutputFileName(unqualify(ctxt.getServletJavaFileName()));
-            g.addStratum(s, true);
+            g.setStratum(s);
 
             String innerClassFileName =
                 classFileName.substring(0, classFileName.indexOf(".class")) +
@@ -180,8 +183,7 @@ public class SmapUtil {
     // Installation logic (from Robert Field, JSR-045 spec lead)
     private static class SDEInstaller {
 
-        private final org.apache.juli.logging.Log log=
-            org.apache.juli.logging.LogFactory.getLog( SDEInstaller.class );
+        private final Log log = LogFactory.getLog(SDEInstaller.class); // must not be static
 
         static final String nameSDE = "SourceDebugExtension";
 
@@ -253,7 +255,7 @@ public class SmapUtil {
                 // if "SourceDebugExtension" symbol not there add it
                 writeUtf8ForSDE();
 
-                // increment the countantPoolCount
+                // increment the constantPoolCount
                 sdeIndex = constantPoolCount;
                 ++constantPoolCount;
                 randomAccessWriteU2(constantPoolCountPos, constantPoolCount);
@@ -700,7 +702,7 @@ public class SmapUtil {
         public void doVisit(Node n) {
             String inner = n.getInnerClassName();
             if (inner != null && !map.containsKey(inner)) {
-                map.put(inner, new SmapStratum("JSP"));
+                map.put(inner, new SmapStratum());
             }
         }
 
